readme_template = """
[![Build Status](https://travis-ci.com/{1}/{0}.svg?branch=master)](https://travis-ci.com/{1}/{0})
[![License: MIT](https://img.shields.io/badge/License-MIT-red.svg)](https://opensource.org/licenses/MIT)
[![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
[![HitCount](http://hits.dwyl.io/{1}/{0}.svg)](http://dwyl.io/{1}/{0})
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://github.com/{1}/pull/)
[![GitHub pull-requests](https://img.shields.io/github/issues-pr/Naereen/StrapDown.js.svg)](https://gitHub.com/{1}/{0}/pull/)
[![GitHub version](https://badge.fury.io/gh/Naereen%2FStrapDown.js.svg)](https://github.com/{1}/{0}).
[![Made With](https://img.shields.io/badge/Language-{2}-yellow.svg)](https://github.com/TralahM)

# {0}.


[![{1}](https://img.shields.io/badge/Engineer-{1}-blue.svg?style=for-the-badge)](https://github.com/{1})
[![{1}](https://img.shields.io/badge/Maintainer-{1}-green.svg?style=for-the-badge)](https://github.com/{1})

# Documentation

# How to Install

## Building from Source for Developers

```Bash
git clone https://github.com/{1}/{0}.git
cd {0}
```

# Contributing
[See the Contributing File](CONTRIBUTING.rst)


[See the Pull Request File](PULL_REQUEST_TEMPLATE.md)


# Support

# LICENCE

[Read the license here](LICENSE)


# Acknowledgements

[Find me on Twitter](https://twitter.com/TralahM)

[Find me on Kaggle](https://kaggle.com/TralahM)


"""



import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='initgitdoc',
    version='0.3.6',
    scripts=['initgitdoc'],
    author="Tralah M Brian",
    author_email="musyoki.brian@tralahtek.com",
    description="A utility to generate common git repository files, Readmes,Licenses,..etc.",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/TralahM/docrepo",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
